diff src/plugins/plugin_misc_maildir.py @ 2144:1d3f73e065e1

core, jp: component handling + client handling refactoring: - SàT can now handle components - plugin have now a "modes" key in PLUGIN_INFO where they declare if they can be used with clients and or components. They default to be client only. - components are really similar to clients, but with some changes in behaviour: * component has "entry point", which is a special plugin with a componentStart method, which is called just after component is connected * trigger end with a different suffixes (e.g. profileConnected vs profileConnectedComponent), so a plugin which manage both clients and components can have different workflow * for clients, only triggers of plugins handling client mode are launched * for components, only triggers of plugins needed in dependencies are launched. They all must handle component mode. * component have a sendHistory attribute (False by default) which can be set to True to allow saving sent messages into history * for convenience, "client" is still used in method even if it can now be a component * a new "component" boolean attribute tells if we have a component or a client * components have to add themselve Message protocol * roster and presence protocols are not added for components * component default port is 5347 (which is Prosody's default port) - asyncCreateProfile has been renamed for profileCreate, both to follow new naming convention and to prepare the transition to fully asynchronous bridge - createProfile has a new "component" attribute. When used to create a component, it must be set to a component entry point - jp: added --component argument to profile/create - disconnect bridge method is now asynchronous, this way frontends can know when disconnection is finished - new PI_* constants for PLUGIN_INFO values (not used everywhere yet) - client/component connection workflow has been moved to their classes instead of being a host methods - host.messageSend is now client.sendMessage, and former client.sendMessage is now client.sendMessageData. - identities are now handled in client.identities list, so it can be updated dynamically by plugins (in the future, frontends should be able to update them too through bridge) - profileConnecting* profileConnected* profileDisconnected* and getHandler now all use client instead of profile
author Goffi <goffi@goffi.org>
date Sun, 12 Feb 2017 17:55:43 +0100
parents 633b5c21aefd
children 33c8c4973743
line wrap: on
line diff
--- a/src/plugins/plugin_misc_maildir.py	Tue Feb 07 00:15:03 2017 +0100
+++ b/src/plugins/plugin_misc_maildir.py	Sun Feb 12 17:55:43 2017 +0100
@@ -45,7 +45,7 @@
 MAILDIR_PATH = "Maildir"
 CATEGORY = D_("Mail Server")
 NAME = D_('Block "normal" messages propagation')
-# FIXME: (very) old and (very) experimental code, need a big cleaning/review
+# FIXME: (very) old and (very) experimental code, need a big cleaning/review or to be deprecated
 
 
 class MaildirError(Exception):
@@ -82,8 +82,9 @@
         #the triggers
         host.trigger.add("MessageReceived", self.messageReceivedTrigger)
 
-    def profileConnected(self, profile):
-        """Called on profile connection, create profile data"""
+    def profileConnected(self, client):
+        """Called on client connection, create profile data"""
+        profile = client.profile
         self.data[profile] = PersistentBinaryDict("plugin_maildir", profile)
         self.__mailboxes[profile] = {}
 
@@ -93,8 +94,9 @@
                 self.data[profile]["INBOX"] = {"cur_idx": 0}
         self.data[profile].load().addCallback(dataLoaded)
 
-    def profileDisconnected(self, profile):
+    def profileDisconnected(self, client):
         """Called on profile disconnection, free profile's resources"""
+        profile = client.profile
         del self.__mailboxes[profile]
         del self.data[profile]